[tor-commits] [stem/master] Fixing spelling of check_requriements()

atagar at torproject.org atagar at torproject.org
Sun Oct 28 21:38:37 UTC 2012


commit 0afe836c94f83f3e11435cdb9f8a3f33dbb9f106
Author: Damian Johnson <atagar at torproject.org>
Date:   Sun Oct 28 14:37:39 2012 -0700

    Fixing spelling of check_requriements()
    
    Spelling mistake caught by eoinof...
    https://trac.torproject.org/7245
---
 run_tests.py   |    2 +-
 stem/prereq.py |    4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/run_tests.py b/run_tests.py
index 969f28f..266ed0e 100755
--- a/run_tests.py
+++ b/run_tests.py
@@ -272,7 +272,7 @@ def _clean_orphaned_pyc():
 
 if __name__ == '__main__':
   try:
-    stem.prereq.check_requriements()
+    stem.prereq.check_requirements()
   except ImportError, exc:
     print exc
     print
diff --git a/stem/prereq.py b/stem/prereq.py
index 3e899dd..67611fd 100644
--- a/stem/prereq.py
+++ b/stem/prereq.py
@@ -12,7 +12,7 @@ series). Other requirements for complete functionality are...
 
 ::
 
   check_requriements - checks for minimum requirements for running stem
   
   is_python_26 - checks if python 2.6 or later is available
   is_python_27 - checks if python 2.7 or later is available
@@ -26,7 +26,7 @@ import stem.util.log as log
 
 IS_RSA_AVAILABLE = None
 
-def check_requriements():
+def check_requirements():
   """
   Checks that we meet the minimum requirements to run stem. If we don't then
   this raises an ImportError with the issue.
@@ -12,7 +12,7 @@ series). Other requirements for complete functionality are...
 ::
 
-  check_requriements - checks for minimum requirements for running stem
+  check_requirements - checks for minimum requirements for running stem
   
   is_python_26 - checks if python 2.6 or later is available



More information about the tor-commits mailing list